@@ -1,24 +1,21 @@
 #!/bin/sh
 #
-#	tardy - a tar post-processor
-#	Copyright (C) 1996, 1999 Peter Miller;
-#	All rights reserved.
+#       tardy - a tar post-processor
+#       Copyright (C) 1996, 1999, 2008 Peter Miller
 #
-#	This program is free software; you can redistribute it and/or modify
-#	it under the terms of the GNU General Public License as published by
-#	the Free Software Foundation; either version 2 of the License, or
-#	(at your option) any later version.
+#       This program is free software; you can redistribute it and/or modify
+#       it under the terms of the GNU General Public License as published by
+#       the Free Software Foundation; either version 3 of the License, or
+#       (at your option) any later version.
 #
-#	This program is distributed in the hope that it will be useful,
-#	but WITHOUT ANY WARRANTY; without even the implied warranty of
-#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#	GNU General Public License for more details.
+#       This program is distributed in the hope that it will be useful,
+#       but WITHOUT ANY WARRANTY; without even the implied warranty of
+#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#       GNU General Public License for more details.
 #
-#	You should have received a copy of the GNU General Public License
-#	along with this program; if not, write to the Free Software
-#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-#
-# MANIFEST: Test the -downcase functionality
+#       You should have received a copy of the GNU General Public License
+#       along with this program. If not, see
+#       <http://www.gnu.org/licenses/>.
 #
 
 umask 022
@@ -36,21 +33,21 @@ if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi
 
 fail()
 {
-	set +x
-	echo 'FAILED test of the -downcase functionality' 1>&2
-	cd $here
-	find $work -type d -user $USER -exec chmod u+w {} \;
-	rm -rf $work
-	exit 1
+        set +x
+        echo 'FAILED test of the -downcase functionality' 1>&2
+        cd $here
+        find $work -type d -user $USER -exec chmod u+w {} \;
+        rm -rf $work
+        exit 1
 }
 pass()
 {
-	set +x
-	echo PASSED 1>&2
-	cd $here
-	find $work -type d -user $USER -exec chmod u+w {} \;
-	rm -rf $work
-	exit 0
+        set +x
+        echo PASSED 1>&2
+        cd $here
+        find $work -type d -user $USER -exec chmod u+w {} \;
+        rm -rf $work
+        exit 0
 }
 trap \"fail\" 1 2 3 15
 
@@ -68,10 +65,10 @@ chmod 0755 FooBar
 if test $? -ne 0 ; then fail; fi
 for f in I Wonder Just How Well This Will Work
 do
-	cp /dev/null FooBar/$f
-	if test $? -ne 0 ; then fail; fi
-	chmod 0644 FooBar/$f
-	if test $? -ne 0 ; then fail; fi
+        cp /dev/null FooBar/$f
+        if test $? -ne 0 ; then fail; fi
+        chmod 0644 FooBar/$f
+        if test $? -ne 0 ; then fail; fi
 done
 tar cf infile FooBar
 if test $? -ne 0 ; then fail; fi
@@ -82,7 +79,7 @@ if test $? -ne 0 ; then fail; fi
 $bin/tardy -list outfile /dev/null 2> test.out
 if test $? -ne 0 ; then fail; fi
 
-sort +4 < test.out > test.out2
+sort -k 4 < test.out > test.out2
 if test $? -ne 0 ; then fail; fi
 
 cat > ok << 'fubar'
@@ -110,7 +107,7 @@ if test $? -ne 0 ; then fail; fi
 $bin/tardy -list outfile /dev/null 2> test.out
 if test $? -ne 0 ; then fail; fi
 
-sort +4 < test.out > test.out2
+sort -k 4 < test.out > test.out2
 if test $? -ne 0 ; then fail; fi
 
 cat > ok << 'fubar'
